@@ -2,4 +2,4 @@ import importlib.metadata
 
 __version__ = importlib.metadata.version("pard")
 
-from . import grantham
+from . import grantham, sneath
